summaryrefslogtreecommitdiff
path: root/gcc/ginclude
diff options
context:
space:
mode:
authorkenner <kenner@138bc75d-0d04-0410-961f-82ee72b054a4>1995-07-28 12:53:12 +0000
committerkenner <kenner@138bc75d-0d04-0410-961f-82ee72b054a4>1995-07-28 12:53:12 +0000
commit5698dd016bbdf607cfb92372463650ee75c95d6c (patch)
tree3f93b87dd8fe03d2b727c89740d93460ad1d6d84 /gcc/ginclude
parent482dd860d1469c48c8a401b9e955232c904ba83b (diff)
downloadgcc-5698dd016bbdf607cfb92372463650ee75c95d6c.tar.gz
Change every occurance of #if __mips>=3 to #ifdef __mips64.
git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@10179 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/ginclude')
-rw-r--r--gcc/ginclude/va-mips.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/gcc/ginclude/va-mips.h b/gcc/ginclude/va-mips.h
index de2f7820d88..76df3648ec1 100644
--- a/gcc/ginclude/va-mips.h
+++ b/gcc/ginclude/va-mips.h
@@ -29,7 +29,7 @@ typedef char * __gnuc_va_list;
#define __va_ellipsis
#endif
-#if __mips>=3
+#ifdef __mips64
#define __va_rounded_size(__TYPE) \
(((sizeof (__TYPE) + 8 - 1) / 8) * 8)
#else
@@ -54,7 +54,7 @@ typedef char * __gnuc_va_list;
#else
#define va_alist __builtin_va_alist
-#if __mips>=3
+#ifdef __mips64
/* This assumes that `long long int' is always a 64 bit type. */
#define va_dcl long long int __builtin_va_alist; __va_ellipsis
#else
@@ -78,11 +78,11 @@ void va_end (__gnuc_va_list); /* Defined in libgcc.a */
/* We cast to void * and then to TYPE * because this avoids
a warning about increasing the alignment requirement. */
/* The __mips>=3 cases are reversed from the 32 bit cases, because the standard
32 bit calling convention left-aligns all parameters smaller than a word,
- whereas the __mips>=3 calling convention does not (and hence they are
+ whereas the __mips64 calling convention does not (and hence they are
right aligned). */
-#if __mips>=3
+#ifdef __mips64
#ifdef __MIPSEB__
#define va_arg(__AP, __type) \
((__type *) (void *) (__AP = (char *) ((((__PTRDIFF_TYPE__)__AP + 8 - 1) & -8) \
@@ -94,7 +94,7 @@ void va_end (__gnuc_va_list); /* Defined in libgcc.a */
*(__type *) (void *) (__AP - __va_rounded_size (__type)))
#endif
-#else /* not __mips>=3 */
+#else /* not __mips64 */
#ifdef __MIPSEB__
/* For big-endian machines. */
@@ -78,11 +78,11 @@ void va_end (__gnuc_va_list); /* Defined in libgcc.a */
/* We cast to void * and then to TYPE * because this avoids
a warning about increasing the alignment requirement. */
-/* The __mips>=3 cases are reversed from the 32 bit cases, because the standard
+/* The __mips64 cases are reversed from the 32 bit cases, because the standard
32 bit calling convention left-aligns all parameters smaller than a word,